@@ -52,7 +52,7 @@ class BaseQCticSimulator(BaseBackend):
         return self.provider().api
 
     def _res_to_job(self, res):
-        return QCticJob(self, res["job_id"], Qobj.from_dict(res["qobj"]))
+        return QCticJob(self, res["job_id"], Qobj.from_dict(res["qobj"]), remote_job=res)
 
     def _default_backend_status(self):
         return BackendStatus(
