@@ -16,7 +16,7 @@ def _fetch_job_sync(func):
         fetch = kwargs.pop("fetch", False)
 
         if not args[0]._remote_job or fetch:
-            args[0]._fetch_remote_job()
+            args[0].fetch_remote()
 
         return func(*args, **kwargs)
 
@@ -29,7 +29,7 @@ def _fetch_job_async(func):
         fetch = kwargs.pop("fetch", False)
 
         if not args[0]._remote_job or fetch:
-            await args[0]._fetch_remote_job_async()
+            await args[0].fetch_remote_async()
 
         return await func(*args, **kwargs)
 
@@ -105,12 +105,12 @@ class QCticJob(BaseJob):
     def _log_fetch(self):
         _logger.debug("Fetching job: %s", self.job_id())
 
-    def _fetch_remote_job(self):
+    def fetch_remote(self):
         self._log_fetch()
         self._remote_job = self.api.get_job_sync(self.job_id())
         self._fetch_time = time.time()
 
-    async def _fetch_remote_job_async(self):
+    async def fetch_remote_async(self):
         self._log_fetch()
         self._remote_job = await self.api.get_job(self.job_id())
         self._fetch_time = time.time()
@@ -152,7 +152,7 @@ class QCticJob(BaseJob):
         self.api.cancel_job_sync(self.job_id())
 
     @_fetch_job_sync
-    def result(self, poll=False, base_sleep=2, max_sleep=128, sleep_growth=2):
+    def result(self):
         """Return the results of the job.
 
         Args:
@@ -165,17 +165,7 @@ class QCticJob(BaseJob):
             JobError: If there was an error running the experiment on the remote simulator.
         """
 
-        sleep = base_sleep
-
-        while True:
-            res = self._result()
-
-            if res or not poll:
-                return res
-
-            time.sleep(sleep)
-            sleep = min(sleep * sleep_growth, max_sleep)
-            self._fetch_remote_job()
+        return self._result()
 
     @_fetch_job_async
     async def status_async(self):
@@ -188,15 +178,5 @@ class QCticJob(BaseJob):
         await self.api.cancel_job(self.job_id())
 
     @_fetch_job_async
-    async def result_async(self, poll=False, base_sleep=2, max_sleep=128, sleep_growth=2):
-        sleep = base_sleep
-
-        while True:
-            res = self._result()
-
-            if res or not poll:
-                return res
-
-            await asyncio.sleep(sleep)
-            sleep = min(sleep * sleep_growth, max_sleep)
-            await self._fetch_remote_job_async()
+    async def result_async(self):
+        return self._result()
